@@ -1,4 +1,4 @@
 from gcandle.utils.DatabaseClient import DatabaseClient
 
 
-DB_CLIENT = DatabaseClient().init()
+DB_CLIENT = DatabaseClient()
